function [Ytrace, Mrgn, Brgn, trk, Ntrk] = ...
            IAThresholdTracker02intensity(Y, height, width,  Nframes, BGmethod, ThrshCorr)
% used by ImageAnalyzer for tracking a bright neuron by following the centroid after segmentation of a "tracking ROI" 
%input:
% Y: a yellow stack to track and measre
% height, width,  Nframes, bits:properties of the images in the stack
% BGmethod: method of background calculation (n: no; m: median of full frame; r: ROI separate; o: outside of measuring ROI)
%
%output:
% cropY:  cropped yellow stack (keeping neuron in one location)
% Mrgn: region for measuring signal in cropped stacks
% Brgn: region for measuring background in cropped stacks
% cropsize: size of cropped stacks 
% trk: XY of tracking

%need to: fix tracking. break if hits edges.
%% setting up
  if ~exist('ThrshCorr', 'var'),  ThrshCorr=-0.2; end %corrects threshold, try changing this if tracking fails
  if ~exist('height', 'var'),  height=size(Y,1); end
  if ~exist('width', 'var'),  width=size(Y,2); end
  if ~exist('Nframes', 'var'),  Nframes=size(Y,3); end
  Y4trk=double( Y-min(min(min(Y))))/max(max(max(Y-min(min(min(Y))))));
  Ytrace=zeros(Nframes,1); 
%% define ROIs for tracking and measuring


%         I =(Y(:,:,1));
%         scrsz = get(0,'ScreenSize');
%          figure('name','Choose ROIs for tracking and measuring','numbertitle','off','Position',...
%                                     [scrsz(3)/2 scrsz(4)/2 scrsz(3)/2.5 scrsz(4)/2.5]),imshow(I,'DisplayRange',[],'InitialMagnification',300); axis image
%         disp ('select an ROI for tracking (large enough to contain the neuron in the next frame)')
%         [Trgn, xT, yT] = roipoly; % asks the user to define an ROI that includes neuron for tracking
%         cropsize = [round(max(xT)-min(xT))-1, round(max(yT)-min(yT))-1, Nframes]; %limiting box used to crop around tracking ROI
       trk = zeros(Nframes);
       hFROI= figure('Position',get(0,'ScreenSize'));
       hIROI=show_image(Y4trk(:,:,1), 'Magnification', 0.4, 'Handle', hFROI); 
       disp ('select an ROI for tracking (large enough to contain the neuron in the next frame)')
       [Trgn, xT, yT] = roipoly;
       cropsize = [round(max(xT)-min(xT))-1, round(max(yT)-min(yT))-1];
        for i = 1:10 %(track a few times to put the T-ROI around object)
            Thrshld = ThrshCorr + graythresh(imadjust(imcrop (Y4trk(:,:,1), [round(min(xT)), round(min(yT)), cropsize(1), cropsize(2)]))); %can try using histeq or adapthisteq instead of imadjust 
            %Thrshld = ThrshCorr + graythresh(histeq(imcrop (Y4trk(:,:,1), [round(min(xT)), round(min(yT)), cropsize(1), cropsize(2)])));
            %Thrshld = ThrshCorr + graythresh(adapthisteq(imcrop (Y4trk(:,:,1), [round(min(xT)), round(min(yT)), cropsize(1), cropsize(2)])));
            
            bw = ~(im2bw(imadjust(Y4trk(:,:,1)), Thrshld));%this line is very demanding and can fail to produce a bw (change threshold?
            bw = ~(bw & Trgn)&Trgn; %deletes area around ROI
   %         bw = bwareaopen(bw,round (0.5*bwarea(bw))); %gets rid of all but biggest object (might have no object if there are many small ones...)
            s = regionprops(double(bw), 'centroid');
            roi_prprt = regionprops(double(Trgn), 'centroid');%get centroid of ROI here       
            xMove = (roi_prprt.Centroid(1)-s.Centroid(1));
            yMove = (roi_prprt.Centroid(2)-s.Centroid(2));
            xT = xT-xMove; yT= yT-yMove; %moves ROI by difference to centroid of detected object
            [Trgn, xT, yT] = roipoly(Trgn,xT,yT); %redefine ROI
        end
        %close %close the tracking ROI figure
        
        %figure('name','Tracking and measuring','numbertitle','on',...
        %            'Position',[scrsz(3)/2 scrsz(4)/2 scrsz(3)/2.5 scrsz(4)/2.5]):
        %get measuring ROI
        cla
        imshow(Y(:,:,1),'DisplayRange',[],'InitialMagnification',300)     
        hold(imgca,'on')           
        plot(imgca, xT, yT,':r','LineWidth',1); % shows new location of ROI
        disp ('select ROI for measuring (smaller and included within neuron)')
        sound([sin(1:.2:400), sin(1:.25:100), sin(1:.3:300)]) % "Hey! You! 
        [Mrgn, xM, yM] = roipoly; % asks the user to define a measuring ROI
%get background ROI if needed or establish that outside of
%measuring ROI is background
        if BGmethod == 'r'
        %close %close the tracking ROI figure
        %figure('name','Tracking and measuring','numbertitle','on','Position',[scrsz(3)/2 scrsz(4)/2 scrsz(3)/2.5 scrsz(4)/2.5]);
        cla
        imshow(Y4trk(:,:,1),'DisplayRange',[],'InitialMagnification',300)     
        hold(imgca,'on')           
        plot(imgca, xT, yT,':r','LineWidth',1); hold on
        plot(imgca, xM, yM,'r','LineWidth',1);% shows new location of ROIs
        disp ('select ROI for Background measuring (smaller than tracking ROI and NOT including neuron)')
        sound([sin(1:.2:400), sin(1:.25:100), sin(1:.3:300)]) % "Hey! You! 
        [Brgn] = roipoly; % asks the user to define a background ROI
        else 
            Brgn = []; %not sure this is needed
        end        
        %
        disp ('Tracking....')
%% track (flipping throrugh the stack)
tic
trk = zeros (Nframes, 2);
cropY = zeros (cropsize(2)+1, cropsize(1)+1, Nframes);
Mrgn = imcrop (Mrgn, [min(xT), min(yT), cropsize(1),cropsize(2)]); %crops Mrgn to measure cropY
if BGmethod == 'r', Brgn = imcrop (Brgn, [min(xT), min(yT),cropsize(1), cropsize(2)]); end %crops
 
  for Ntrk = 1:Nframes
    I =(Y4trk(:,:,Ntrk));
    cropI = imcrop (I, [round(min(xT)), round(min(yT)), cropsize(1), cropsize(2)]);     
    Thrshld = ThrshCorr + graythresh(imadjust(cropI));

    bw = ~(im2bw(imadjust(I), Thrshld));%this line where tracking might fail to produce a bw (change threshold?
    bw = ~(bw & Trgn)&Trgn; %deletes (sets to 0) area around ROI
    bw = bwareaopen(bw,round (0.5*bwarea(bw))); %gets rid of all but biggest object (bigger than half the occupied pixels)
%       last_s = s;
%       s = regionprops(double(bw), 'centroid');
%      if isempty(s), s = last_s; end %this keeps last tracking point in case of a blanc bw
    if ~isempty(regionprops(double(bw), 'centroid')), s = regionprops(double(bw), 'centroid'); end%niceralternative for keeping last value
    roi_prprt = regionprops(double(Trgn), 'centroid');%gets centroid of ROI
  %  if (max(xT)>width)||(max(yT)>height),error('Tracked out of frame!'), end
        xMove = (roi_prprt.Centroid(1)-s.Centroid(1));
        yMove = (roi_prprt.Centroid(2)-s.Centroid(2));
        xT = xT-xMove; yT= yT-yMove; %moves ROI by difference to centroid of detected object
        [Trgn, xT, yT] = roipoly(Trgn,xT,yT); %redefine ROI
        xM = xM-xMove; yM= yM-yMove; %moves ROI by difference to centroid of detected object
        
        keepgoing = min([min([xT yT]) min([xM yM])])>5 && max([max(xM) max(xT)])< (width-5) &&...
                                                                max([max(yM) max(yT)])< (height-5); %checks if out of bounds
       if ~keepgoing,
           Ntrk=Ntrk-1; %#ok<FXSET> %last good one
           Ytrace=Ytrace(1:Ntrk); %cut to size get rid of zeros
           break 
       end
    cla
    imshow(I,'DisplayRange',[])
    hold(imgca,'on')
    plot(imgca, xM, yM,'-b','LineWidth',1); % shows new location of measuring ROI after tracking
    drawnow; % this is currently the most demanding line
    trk(Ntrk,:) = [s.Centroid(1), s.Centroid(2)]; %keeps a file with all tracking position
    cropY (:,:,Ntrk) = imcrop (Y(:,:,Ntrk), [round(min(xT)), round(min(yT)), cropsize(1), cropsize(2)]);
     cropYi = cropY(:,:,Ntrk);
     Ytrace(Ntrk) = mean(cropYi(Mrgn));  %measuring ROI in yellow      
  end
 hold on;
 plot (trk(1:Ntrk,1),trk(1:Ntrk,2), ':r', 'LineWidth',2)
 
%%  presenting a movie (if run stand alone): 
if nargin == 0, % not do this if run as a function  
sound([sin(1:.2:400), sin(1:.25:100), sin(1:.3:300)]) % "Hey! You! watch this movie!"
scrsz = get(0,'ScreenSize');
figure('name','cropped yelow track','Position',[10 scrsz(4)/4 scrsz(3)/2 scrsz(4)*2/3]);
Clims = [min(min(min(Y (:,:,:)))), max(max(max(Y (:,:,:))))];% set image color scale to smooth the movie
    for i = Nframes:-1:1,
     imagesc(cropY(:,:,i), Clims); colormap (jet); axis image;
     drawnow;
     cropYi = cropY(:,:,i); 
     roimean(i,1) = mean(cropYi(Mrgn)); %#ok<AGROW> %measuring ROI in yellow
    end;
    figure; plot (roimean)
end