function [Ytrace, rYtrace,  Mrgn, Brgn, trk, Ntrk] = ...
            IAZoomManualTracker03intensity(Y, rY, height, width,  Nframes, BGmethod, FirstFrameNumber)
%% IAManualTracker03intensity 
%***The new trait in 03: added the info of red channel, so there are
%variables like rY, crop_rY, ect.
% used by ImageAnalyzer for tracking a bright neuron by asking the user to
% select an ROI to zoom in then a zoommed ROI to measure and then to
% click on the center of the neuron after each step.
%input:
% Y: a yellow stack to track and measre
% rY: a yellow stack of the red channel to track and measre
% height, width,  Nframes, bits:properties of the images in the stack
% BGmethod: method of background calculation (n: no; m: median of full frame; r: ROI separate; o: outside of measuring ROI)
%
%output:
% cropY:  cropped yellow stack (keeping neuron in one location)
% Mrgn: region for measuring signal in cropped stacks
% Brgn: region for measuring background in cropped stacks
% cropsize: size of cropped stacks 
% trk: XY of tracking

%need to: fix tracking. break if hits edges.

% Written by Gal Haspel 160608
%% setting up
  if ~exist('height', 'var'),  height=size(Y,1); end
  if ~exist('width', 'var'),  width=size(Y,2); end
  if ~exist('Nframes', 'var'),  Nframes=size(Y,3); end
  Ytrace=zeros(Nframes,1); %calcium img channel
  rYtrace=zeros(Nframes,1); %red channel
  %ratioYtrace=zeros(Nframes,1); %ratio of calcium channel to reference channel
  trk = zeros (Nframes, 2);
  
%% define ROI to zoom in
    hZROI= figure('Position',get(0,'ScreenSize'));
        hImagescAxis = axes('parent', hZROI);
        hImage=imshow(Y(:,:,1), [], 'parent', hImagescAxis, 'colormap', parula,'Border','tight','InitialMagnification','fit'); %#ok<NASGU> % 'DisplayRange', [min(min(Y(:,:,1))) max(max(Y(:,:,1)))]
    rect = getrect(hImagescAxis); %//select roi with mouse to zoom
    rect = [floor(rect(1)), floor(rect(2)), ceil(rect(3)), ceil(rect(4)) ];
    cropI = Y( rect(2) : (rect(2)+rect(4)) , rect(1) : (rect(1)+rect(3)) , 1 );  %//store roi in matrix
    crop_rI = rY( rect(2) : (rect(2)+rect(4)) , rect(1) : (rect(1)+rect(3)) , 1 );    
    %crop_ratioI = double(cropI)./double(crop_rI);
    
    hImageAxis1=subplot(2,2,1);
        hImagefull=imshow(Y(:,:,1), [], 'parent', hImageAxis1, 'colormap', parula,'Border','tight','InitialMagnification','fit'); %#ok<NASGU>
        hold(imgca,'on');           
        rectangle('Position',rect, 'LineWidth',1, 'EdgeColor','k') 
        hImageAxis2=subplot(2,2,3);
        hImageZoom=imshow(cropI, [],'parent',  hImageAxis2, 'colormap', parula,'Border','tight','InitialMagnification','fit');  %#ok<NASGU>
    shg

%% define ROI for tracking and measuring (and BG if needed)
        disp ('select ROI for measuring (includs and twice as large as neuron)')
        sound([sin(1:.2:400), sin(1:.25:100), sin(1:.3:300)]) % "Hey! You! 
        [Mrgn, xM, yM] = roipoly; % asks the user to define a measuring ROI
        hold(imgca,'on')           
        plot(imgca, xM, yM,':r','LineWidth',1);% shows location of measuring ROI
        xOld = round( min(xM) + (max(xM)-min(xM))/2);
        yOld = round(min(yM) + (max(yM)-min(yM))/2);
        plot (imgca, xOld, yOld, 'Xr'); % shows current location of center of ROI (to help position next mouse click)
%center rect around xOld/yOld
        rect(1) = xOld+rect(1) - rect(3)/2; 
        rect(2) = yOld+rect(2) - rect(4)/2;
% prevent crop rect from hitting edges
            if rect(1)<0, rect(1)=0; end
            if rect(2)<0, rect(2)=0; end
            if (rect(1)+rect(3))>width, rect(1)= width-rect(3); end 
            if (rect(2)+rect(4))> height, rect(2) = height-rect(4); end
%get background ROI if needed or establish that outside of measuring ROI is background       
        if BGmethod == 'r'
            hold(imgca,'on')           
            disp ('select ROI for Background measuring (NOT including neuron)')
            sound([sin(1:.2:400), sin(1:.25:100),sin(1:.25:100), sin(1:.3:300)]) % "Hey! You! 
            [Brgn] = roipoly; % asks the user to define a background ROI
        else 
            Brgn = []; %not sure this is needed
        end        

%% track (flipping throrugh the stack)
tic
I =(Y(:,:,1));
rI =  rY(:,:,1);
%ratioI = double(I)./double(rI);
cropY = zeros([size(cropI), Nframes]);
crop_rY = zeros([size(cropI), Nframes]);
%crop_ratioY = zeros([size(cropI), Nframes]);
cropY(:,:,1) = cropI;
crop_rY(:,:,1) = crop_rI;
%crop_ratioY(:,:,1) = crop_ratioI;
%switch case for backgroun options
    switch BGmethod
        case 'n'%'No background sub'
            BGround = 0;
        case 'm' %'Median of image'
            BGround = median(I(:));
            rBGround = median(rI(:));
            %ratioBGround = median(ratioI(:));
        case 'o' %'Median except ROI'
            Ibg=I(~Mrgn);
            BGround = median(Ibg(:));
        case 'r' %'Background ROI'
            Ibg=I(~Mrgn);
            BGround = mean(Ibg(:));
    end
 %store measured values of intensity and location   
    PixelValues = cropI(Mrgn);%measuring ROI. Should subtract BG.
    rPixelValues = crop_rI(Mrgn);
    %ratioPixelValues = crop_ratioI(Mrgn);
    Ytrace(1) = mean(PixelValues(PixelValues>prctile(PixelValues,50)))-BGround;  %mean of top 50% change value to measure top X% of pixels  
    rYtrace(1) = mean(rPixelValues(rPixelValues>prctile(rPixelValues,50)))-rBGround;
    %ratioYtrace(1) = mean(ratioPixelValues);
    trk(1,:) = [xOld+rect(1), yOld+rect(2)]; % First tracking position
    hImageAxis3=subplot(2,2,4);

% tracking. user clicks on new location on righ hand image       
  %for Ntrk = 2:Nframes
  Ntrk = 0; 
  while  Ntrk<Nframes
    Ntrk = Ntrk+1;
    I =(Y(:,:,Ntrk));
    rI = rY(:,:,Ntrk);
    %ratioI = double(I)./double(rI);
    cropI = I( rect(2) : (rect(2)+rect(4)) , rect(1) : (rect(1)+rect(3))); 
    crop_rI = rI( rect(2) : (rect(2)+rect(4)) , rect(1) : (rect(1)+rect(3))); 
    %crop_ratioI = ratioI( rect(2) : (rect(2)+rect(4)) , rect(1) : (rect(1)+rect(3)));
       cla(hImageAxis1)
        hImagefull=imshow(Y(:,:,Ntrk), [], 'parent', hImageAxis1, 'colormap', parula,'Border','tight','InitialMagnification','fit'); %#ok<NASGU>
        hold(imgca,'on')           
        rectangle('Position',rect, 'LineWidth',1, 'EdgeColor','k') 
       cla(hImageAxis2)
       if Ntrk==1 %the first frame is centered and clicked to minimize carried user error
       hImageZoomNext=imshow(cropY(:,:,Ntrk), [],'parent',  hImageAxis2, 'colormap', parula,'Border','tight','InitialMagnification','fit');  %#ok<NASGU>
       else
       hImageZoomNext=imshow(cropY(:,:,Ntrk-1), [],'parent',  hImageAxis2, 'colormap', parula,'Border','tight','InitialMagnification','fit');  %#ok<NASGU>
       end
        hold(imgca,'on')           
        plot(imgca, xM, yM,':r','LineWidth',1);% shows location of last measuring ROI
        plot (imgca, xOld, yOld, 'Xr');        
       cla(hImageAxis3)
        hImageZoom=imshow(cropI, [],'parent',  hImageAxis3, 'colormap', parula,'Border','tight','InitialMagnification','fit');  %#ok<NASGU>
        hold(imgca,'on')           
        plot(imgca, xM, yM,':r','LineWidth',1);% shows location of last measuring ROI
        plot (imgca, xOld, yOld, 'Xr');
        text(20, 20, num2str(FirstFrameNumber+Ntrk), 'FontSize',8, 'color', 'white')% shows frame number or new image
        [xNew, yNew, keystroke] = ginput(1); %get user input on new location of center. keystrokes to abort: q, a, s
        xNew = round(xNew); yNew = round(yNew);
        xMove = (xOld-xNew);
        yMove = (yOld-yNew);
        xM = xM-xMove; yM = yM-yMove; %moves ROI by difference to new point
%center rect around xOld/yOld
        rect(1) = xNew+rect(1) - rect(3)/2; 
        rect(2) = yNew+rect(2) - rect(4)/2;  
%         rect(1) = rect (1)-xMove;
%         rect(2) = rect(2)-yMove;
% prevent crop rect from hitting edges
            if rect(1)<0, rect(1)=0; end
            if rect(2)<0, rect(2)=0; end
            if (rect(1)+rect(3))>width, rect(1)= width-rect(3); end 
            if (rect(2)+rect(4))> height, rect(2) = height-rect(4); end
% check for keystroke: abort 
   keepgoing = rect(1)>0 && rect(2)>0 && (rect(1)+rect(3))<=width && (rect(2)+rect(4))<= height&&...
                                        keystroke~=113&&keystroke~=115&&keystroke~=97; %checks if out of bounds or keystroke abort %keystroke [q a or s] will stop analyzing
   if ~keepgoing
       Ntrk=Ntrk-1; % %last good one
       Ytrace=Ytrace(1:Ntrk); 
       rYtrace=rYtrace(1:Ntrk);%cut to size get rid of zeros
       %ratioYtrace=ratioYtrace(1:Ntrk);
       break 
   end
    cla
    trk(Ntrk,:) = [xNew+rect(1), yNew+rect(2)]; %keeps a file with all tracking position
    cropY(:,:,Ntrk) = cropI;
    crop_rY(:,:,Ntrk) = crop_rI;
    %crop_ratioY(:,:,Ntrk) = crop_ratioI;
% switch case for backgroun options
    switch BGmethod
        case 'n'%'No background sub'
            BGround = 0;
        case 'm' %'Median of image'
            BGround = median(I(:));
            rBGround = median(rI(:));
            %ratioBGround = median(ratioI(:));
        case 'o' %'Median except ROI'
            Ibg=I(~Mrgn);
            BGround = median(Ibg(:));
        case 'r' %'Background ROI'
            Ibg=I(~Mrgn);
            BGround = mean(Ibg(:));
    end
 % store measured values of intensity and location   
    PixelValues = cropI(Mrgn);%measuring ROI. Should subtract BG.
    rPixelValues = crop_rI(Mrgn);
    Ytrace(Ntrk) = mean(PixelValues(PixelValues>prctile(PixelValues,50)))-BGround;  %mean of top 50% change value to measure top X% of pixels  
    rYtrace(Ntrk) = mean(rPixelValues(rPixelValues>prctile(rPixelValues,50)))-rBGround;
    %ratioYtrace(Ntrk) = mean(ratioPixelValues);
    xOld = xNew;
    yOld = yNew;
  % check for keystroke: one back
    if keystroke== 98, Ntrk = Ntrk-2; end % 98 is 'b' key
  end
    hImagefull=imshow(I, [], 'parent', hImageAxis1, 'colormap', parula,'Border','tight','InitialMagnification','fit'); %#ok<NASGU>
    hold('on') 
    plot (hImageAxis1, trk(1:Ntrk,1),trk(1:Ntrk,2), 'k:O')
 
%%  presenting a movie (if run stand alone): 
if nargin == 0 % not do this if run as a function  
sound([sin(1:.2:400), sin(1:.25:100), sin(1:.3:300)]) % "Hey! You! watch this movie!"
scrsz = get(0,'ScreenSize');
figure('name','cropped yelow track','Position',[10 scrsz(4)/4 scrsz(3)/2 scrsz(4)*2/3]);
Clims = [min(min(min(Y (:,:,:)))), max(max(max(Y (:,:,:))))];% set image color scale to smooth the movie
    for i = Nframes:-1:1
     imagesc(cropY(:,:,i), Clims); colormap (jet); axis image;
     drawnow;
     cropYi = cropY(:,:,i); 
     roimean(i,1) = mean(cropYi(Mrgn)); %measuring ROI in yellow
    end
    figure; plot (roimean)
end